==> google_cloud_managed_identities-1.7.0-py2.py3-none-any.whl: google/cloud/managedidentities_v1/services/managed_identities_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union

import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1, operations_v1
from google.api_core import retry as retries
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.longrunning import operations_pb2  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.managedidentities_v1 import gapic_version as package_version
from google.cloud.managedidentities_v1.types import managed_identities_service, resource

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)


class ManagedIdentitiesServiceTransport(abc.ABC):
    """Abstract transport class for ManagedIdentitiesService."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    DEFAULT_HOST: str = "managedidentities.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(
                    api_audience if api_audience else host
                )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.create_microsoft_ad_domain: gapic_v1.method.wrap_method(
                self.create_microsoft_ad_domain,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.reset_admin_password: gapic_v1.method.wrap_method(
                self.reset_admin_password,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_domains: gapic_v1.method.wrap_method(
                self.list_domains,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_domain: gapic_v1.method.wrap_method(
                self.get_domain,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.update_domain: gapic_v1.method.wrap_method(
                self.update_domain,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.delete_domain: gapic_v1.method.wrap_method(
                self.delete_domain,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.attach_trust: gapic_v1.method.wrap_method(
                self.attach_trust,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.reconfigure_trust: gapic_v1.method.wrap_method(
                self.reconfigure_trust,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.detach_trust: gapic_v1.method.wrap_method(
                self.detach_trust,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.validate_trust: gapic_v1.method.wrap_method(
                self.validate_trust,
                default_timeout=60.0,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def operations_client(self):
        """Return the client designed to process long-running operations."""
        raise NotImplementedError()

    @property
    def create_microsoft_ad_domain(
        self,
    ) -> Callable[
        [managed_identities_service.CreateMicrosoftAdDomainRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def reset_admin_password(
        self,
    ) -> Callable[
        [managed_identities_service.ResetAdminPasswordRequest],
        Union[
            managed_identities_service.ResetAdminPasswordResponse,
            Awaitable[managed_identities_service.ResetAdminPasswordResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_domains(
        self,
    ) -> Callable[
        [managed_identities_service.ListDomainsRequest],
        Union[
            managed_identities_service.ListDomainsResponse,
            Awaitable[managed_identities_service.ListDomainsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_domain(
        self,
    ) -> Callable[
        [managed_identities_service.GetDomainRequest],
        Union[resource.Domain, Awaitable[resource.Domain]],
    ]:
        raise NotImplementedError()

    @property
    def update_domain(
        self,
    ) -> Callable[
        [managed_identities_service.UpdateDomainRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def delete_domain(
        self,
    ) -> Callable[
        [managed_identities_service.DeleteDomainRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def attach_trust(
        self,
    ) -> Callable[
        [managed_identities_service.AttachTrustRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def reconfigure_trust(
        self,
    ) -> Callable[
        [managed_identities_service.ReconfigureTrustRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def detach_trust(
        self,
    ) -> Callable[
        [managed_identities_service.DetachTrustRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def validate_trust(
        self,
    ) -> Callable[
        [managed_identities_service.ValidateTrustRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("ManagedIdentitiesServiceTransport",)

==> google_cloud_managed_identities-1.9.1-py2.py3-none-any.whl: google/cloud/managedidentities_v1/services/managed_identities_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union

import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1, operations_v1
from google.api_core import retry as retries
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.longrunning import operations_pb2  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.managedidentities_v1 import gapic_version as package_version
from google.cloud.managedidentities_v1.types import managed_identities_service, resource

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)


class ManagedIdentitiesServiceTransport(abc.ABC):
    """Abstract transport class for ManagedIdentitiesService."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    DEFAULT_HOST: str = "managedidentities.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to (default: 'managedidentities.googleapis.com').
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(
                    api_audience if api_audience else host
                )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

    @property
    def host(self):
        return self._host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.create_microsoft_ad_domain: gapic_v1.method.wrap_method(
                self.create_microsoft_ad_domain,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.reset_admin_password: gapic_v1.method.wrap_method(
                self.reset_admin_password,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_domains: gapic_v1.method.wrap_method(
                self.list_domains,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_domain: gapic_v1.method.wrap_method(
                self.get_domain,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.update_domain: gapic_v1.method.wrap_method(
                self.update_domain,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.delete_domain: gapic_v1.method.wrap_method(
                self.delete_domain,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.attach_trust: gapic_v1.method.wrap_method(
                self.attach_trust,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.reconfigure_trust: gapic_v1.method.wrap_method(
                self.reconfigure_trust,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.detach_trust: gapic_v1.method.wrap_method(
                self.detach_trust,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.validate_trust: gapic_v1.method.wrap_method(
                self.validate_trust,
                default_timeout=60.0,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def operations_client(self):
        """Return the client designed to process long-running operations."""
        raise NotImplementedError()

    @property
    def create_microsoft_ad_domain(
        self,
    ) -> Callable[
        [managed_identities_service.CreateMicrosoftAdDomainRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def reset_admin_password(
        self,
    ) -> Callable[
        [managed_identities_service.ResetAdminPasswordRequest],
        Union[
            managed_identities_service.ResetAdminPasswordResponse,
            Awaitable[managed_identities_service.ResetAdminPasswordResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_domains(
        self,
    ) -> Callable[
        [managed_identities_service.ListDomainsRequest],
        Union[
            managed_identities_service.ListDomainsResponse,
            Awaitable[managed_identities_service.ListDomainsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_domain(
        self,
    ) -> Callable[
        [managed_identities_service.GetDomainRequest],
        Union[resource.Domain, Awaitable[resource.Domain]],
    ]:
        raise NotImplementedError()

    @property
    def update_domain(
        self,
    ) -> Callable[
        [managed_identities_service.UpdateDomainRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def delete_domain(
        self,
    ) -> Callable[
        [managed_identities_service.DeleteDomainRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def attach_trust(
        self,
    ) -> Callable[
        [managed_identities_service.AttachTrustRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def reconfigure_trust(
        self,
    ) -> Callable[
        [managed_identities_service.ReconfigureTrustRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def detach_trust(
        self,
    ) -> Callable[
        [managed_identities_service.DetachTrustRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def validate_trust(
        self,
    ) -> Callable[
        [managed_identities_service.ValidateTrustRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("ManagedIdentitiesServiceTransport",)
